<?php
/**
* @package phpBB Extension - Flip Images BBCode
* @copyright (c) 2023 Sniper_E - http://sniper-e.net
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*/

namespace sniper\flipimages\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface
{
	/** @var \phpbb\user */
	protected $user;
	/** @var \phpbb\template\template */
	protected $template;
	/** @var \phpbb\auth\auth */
	protected $auth;
	/** @var \phpbb\config\config */
	protected $config;
	/** @var \phpbb\extension\manager */
	protected $extension_manager;

	/**
	* Constructor
	*
	* @param \phpbb\user                 $user
	* @param \phpbb\template\template    $template
	* @param \phpbb\auth\auth            $auth
	* @param \phpbb\config\config        $config
	*
	*/
	public function __construct(
		\phpbb\user $user,
		\phpbb\template\template $template,
		\phpbb\auth\auth $auth,
		\phpbb\config\config $config,
		\phpbb\extension\manager $extension_manager)
	{
		$this->user              = $user;
		$this->template          = $template;
		$this->auth              = $auth;
		$this->config            = $config;
		$this->extension_manager = $extension_manager;
	}

	static public function getSubscribedEvents()
	{
		return array(
			'core.permissions'           => 'permissions',
			'core.user_setup'            => 'load_language_on_setup',
			'core.page_header_after'     => 'page_header_after',
			'core.adm_page_header_after' => 'adm_page_header_after',
		);
	}

	public function permissions($event)
	{
		$permissions = $event['permissions'];
		$permissions['u_use_flipimages_bbcode'] = array('lang' => 'ACL_U_USE_FLIPIMAGES_BBCODE', 'cat' => 'post');
		$event['permissions'] = $permissions;
	}

	public function load_language_on_setup($event)
	{
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
			'ext_name' => 'sniper/flipimages',
			'lang_set' => 'common',
		);
		$event['lang_set_ext'] = $lang_set_ext;
	}

	public function page_header_after($event)
	{
		$this->assign_authors();
		$this->template->assign_vars(array(
			'U_USE_FLIPIMAGES_BBCODE' => $this->auth->acl_get('u_use_flipimages_bbcode') ? true : false,
		));
	}
	
	protected function assign_authors()
	{
		$md_manager = $this->extension_manager->create_extension_metadata_manager('sniper/flipimages', $this->template);
		$meta = $md_manager->get_metadata();
		$author_homepages = [];

		foreach (array_slice($meta['authors'], 0, 1) as $author)
		{
			$author_homepages[] = sprintf ('<a href="%1$s" title="%2$s &middot; %1$s">%3$s </a>', $author['homepage'], $author['sitename'], $author['name']);
		}

		$this->template->assign_vars(array(
			'FLIPIMAGES_DISPLAY_NAME'     => $meta['extra']['display-name'],
			'FLIPIMAGES_VERSION'          => $meta['version'],
			'FLIPIMAGES_AUTHOR_HOMEPAGES' => implode(' &amp; ', $author_homepages),
		));
	}

	public function adm_page_header_after($event)
	{
		$this->template->assign_vars(array(
		));
	}
}
